pub struct ScalarSignature {
pub r8: BabyJubPoint,
pub s: BabyJubScalar,
}Expand description
Direct-scalar signature with checked subgroup points and a canonical response scalar.
Fields
r8: BabyJubPoints: BabyJubScalarImplementations
Sourceimpl ScalarSignature
impl ScalarSignature
Sourcepub fn to_signature(&self) -> Signature
pub fn to_signature(&self) -> Signature
Convert to the established witness signature shape without changing values.